@@ -91,6 +91,7 @@ module Heist
 import           Control.Exception.Lifted
 import           Control.Monad.State
 import           Data.ByteString               (ByteString)
+import qualified Data.ByteString.Char8         as BC
 import qualified Data.ByteString               as B
 import           Data.Either
 import qualified Data.Foldable                 as F
@@ -98,7 +99,9 @@ import           Data.HashMap.Strict           (HashMap)
 import qualified Data.HashMap.Strict           as Map
 import qualified Data.HeterogeneousEnvironment as HE
 import           Data.Map.Syntax
+#if !MIN_VERSION_base(4,11,0)
 import           Data.Monoid
+#endif
 import           Data.Text                     (Text)
 import qualified Data.Text                     as T
 import           System.Directory.Tree
@@ -306,12 +309,13 @@ preprocess :: (TPath, DocumentFile)
            -> HeistT IO IO (Either String (TPath, DocumentFile))
 preprocess (tpath, docFile) = do
     let tname = tpathName tpath
+        die   = error $ "Preprocess failed because the template `"
+                     ++ BC.unpack tname
+                     ++ "` was not found in the template repository."
     !emdoc <- try $ I.evalWithDoctypes tname
               :: HeistT IO IO (Either SomeException (Maybe X.Document))
     let f !doc = (tpath, docFile { dfDoc = doc })
     return $! either (Left . show) (Right . maybe die f) emdoc
-  where
-    die = error "Preprocess didn't succeed!  This should never happen."
 
 
 ------------------------------------------------------------------------------
